==> em_tasks-0.1.65-py2.py3-none-any.whl: em_tasks/tools/spree/correct_shipstation_orders.py <==
# -*- coding: utf-8 -*-

import datetime
import pdb

from shipstation.api import *

from em_tasks import logger
from em_tasks.store.store_util import StoreUtil
from em_tasks.store.models import *


class ShipstationOrdersCorrector():
  def __init__(self, shipstation_api_key, shipstation_api_password, store_id=None, days=14):
    self.shipstation_api_key = shipstation_api_key
    self.shipstation_api_password = shipstation_api_password
    self.client = ShipStation(key=shipstation_api_key, secret=shipstation_api_password)
    self.days = days
    self.store_id = store_id

  def run(self):
    batch_size = 50

    today = datetime.datetime.utcnow()
    from_date = today - datetime.timedelta(days=self.days)
    ss_orders = dict()
    for order_item in OrderItem.select().where((OrderItem.s_carrier == 'EM') & (OrderItem.s_purchase_date > from_date)).execute():
      ss_order = StoreUtil.convert_order_item_to_shipstation_order(order_item)
      if not ss_order:
        continue

      ss_orders[ss_order.order_number] = ss_order

    to_update = []

    order_numbers = list(ss_orders.keys())
    for ss in ShipstationShipment.select().where(ShipstationShipment.order_number.in_(order_numbers)).execute():
      if ss.carrier_code and ss.tracking_number:
        logger.debug('[OrderShipped] OrderNumber: %s, Carrier: %s, Tracking: %s', ss.order_number, ss.carrier_code, ss.tracking_number)
        ss_orders.pop(ss.order_number, None)

    order_numbers = list(ss_orders.keys())
    for so in ShipstationOrder.select().where(ShipstationOrder.order_number.in_(order_numbers)).execute():
      ss_order = ss_orders.pop(so.order_number, None)

      ss_order.order_id = so.order_id
      ss_order.order_key = so.order_key
      status = 'awaiting_shipment'
      ss_order.set_status(status)
      logger.debug('[OrderStatusChange] OrderNumber: %s, Status: %s', so.order_number, status)
      to_update.append(ss_order)

    logger.info('ShipstationOrdersToUpdate: %s', len(to_update))

    if to_update:
      chunks = [to_update[x:x + batch_size] for x in range(0, len(to_update), batch_size)]
      for chunk in chunks:
        for so in chunk:
          self.client.add_order(so)
        try:
          resp = self.client.submit_orders()
          self.client.clear_orders()
          self.save_shipstation_orders(resp)
          logger.info('[ShipstationOrdersUpdated] %s', resp.json())
        except Exception as e:
          logger.exception(e)

  def save_shipstation_orders(self, resp):
    sos = dict()
    res = resp.json()
    for result in res['results']:
      succeed = result.get('success', True)
      if not succeed:
        continue

      order_number = result['orderNumber']
      sos[order_number] = {
        'order_id': result['orderId'],
        'order_number': result['orderNumber'],
        'order_key': result['orderKey']
      }

    order_numbers = list(sos.keys())
    for so in ShipstationOrder.select().where(ShipstationOrder.order_number.in_(order_numbers)).execute():
      if so.order_number not in sos:
        continue

      sso = sos.pop(so.order_number)
      if so.order_id != sso['order_id'] or so.order_key != sso['order_key']:
        so.order_id = sso['order_id']
        so.order_key = sso['order_key']
        so.save()


if __name__ == '__main__':
  from em_tasks.store.models import *

  init_store('34.75.174.209', 'superem', 'aySpYkG4p7S', 'everymarket')

  shipstation_api_key = '0bb92934d53442cd858e4af4f11eff44'
  shipstation_api_password = '4670c2c2732b4ea69c9305046f219d74'
  store_id = None
  days = 30
  corrector = ShipstationOrdersCorrector(shipstation_api_key, shipstation_api_password, store_id, days)
  corrector.run()

==> em_tasks-0.1.69-py2.py3-none-any.whl: em_tasks/tools/spree/correct_shipstation_orders.py <==
# -*- coding: utf-8 -*-

import datetime
import pdb

from shipstation.api import *

from em_tasks import logger
from em_tasks.store.store_util import StoreUtil
from em_tasks.store.models import *


class ShipstationOrdersCorrector():
  def __init__(self, shipstation_api_key, shipstation_api_password, store_id=None, days=14):
    self.shipstation_api_key = shipstation_api_key
    self.shipstation_api_password = shipstation_api_password
    self.client = ShipStation(key=shipstation_api_key, secret=shipstation_api_password)
    self.days = days
    self.store_id = store_id

  def run(self):
    batch_size = 50

    today = datetime.datetime.utcnow()
    from_date = today - datetime.timedelta(days=self.days)
    ss_orders = dict()
    for order_item in OrderItem.select().where((OrderItem.s_carrier == 'EM') & (OrderItem.s_purchase_date > from_date)).execute():
      ss_order = StoreUtil.convert_order_item_to_shipstation_order(order_item)
      if not ss_order:
        continue

      ss_orders[ss_order.order_number] = ss_order

    to_update = []

    order_numbers = list(ss_orders.keys())
    for ss in ShipstationShipment.select().where(ShipstationShipment.order_number.in_(order_numbers)).execute():
      if ss.carrier_code and ss.tracking_number:
        logger.debug('[OrderShipped] OrderNumber: %s, Carrier: %s, Tracking: %s', ss.order_number, ss.carrier_code, ss.tracking_number)
        ss_orders.pop(ss.order_number, None)

    pdb.set_trace()

    order_numbers = list(ss_orders.keys())
    for so in ShipstationOrder.select().where(ShipstationOrder.order_number.in_(order_numbers)).execute():
      ss_order = ss_orders.pop(so.order_number, None)

      ss_order.order_key = so.order_key
      status = 'awaiting_shipment'
      ss_order.set_status(status)
      # logger.debug('[OrderStatusChange] OrderNumber: %s, Status: %s', so.order_number, status)
      if so.order_number.find('EM20-6976019') != -1:
        to_update.append(ss_order)

    logger.info('ShipstationOrdersToUpdate: %s', len(to_update))

    pdb.set_trace()

    if to_update:
      chunks = [to_update[x:x + batch_size] for x in range(0, len(to_update), batch_size)]
      for chunk in chunks:
        for so in chunk:
          self.client.add_order(so)
        try:
          resp = self.client.submit_orders()
          self.client.clear_orders()
          self.save_shipstation_orders(resp)
          # logger.info('[ShipstationOrdersUpdated] %s', resp.json())
        except Exception as e:
          logger.exception(e)

  def save_shipstation_orders(self, resp):
    sos = dict()
    res = resp.json()
    for result in res['results']:
      order_number = result.get('orderNumber', '')
      if order_number.find('EM20-6976019') != -1:
        pdb.set_trace()
      succeed = result.get('success', False)
      if not succeed:
        logger.info('[ShipstationOrderUpdateFailed] OrderNumber: %s, Error: %s', result.get('orderNumber', ''), result.get('errorMessage', None))
        continue

      order_number = result['orderNumber']
      sos[order_number] = {
        'order_id': result['orderId'],
        'order_number': result['orderNumber'],
        'order_key': result['orderKey']
      }

    order_numbers = list(sos.keys())
    for so in ShipstationOrder.select().where(ShipstationOrder.order_number.in_(order_numbers)).execute():
      if so.order_number not in sos:
        continue

      sso = sos.pop(so.order_number)
      if so.order_id != sso['order_id'] or so.order_key != sso['order_key']:
        so.order_id = sso['order_id']
        so.order_key = sso['order_key']
        so.save()


if __name__ == '__main__':
  from em_tasks.store.models import *

  init_store('34.75.174.209', 'superem', 'aySpYkG4p7S', 'everymarket')

  shipstation_api_key = '0bb92934d53442cd858e4af4f11eff44'
  shipstation_api_password = '4670c2c2732b4ea69c9305046f219d74'
  store_id = None
  days = 30
  corrector = ShipstationOrdersCorrector(shipstation_api_key, shipstation_api_password, store_id, days)
  corrector.run()
